function H = sym_assignment(n,oracle)
% n is the size of the matrix 
% oracle is a function mapping index lists to principal minors

% initialize
H = zeros(n);

% set diagonal
for i = 1:n
  H(i,i) = oracle(i);
end

% set off-diagonal magnitudes
for i = 2:n
  for j = 1:i-1
    H(i,j) = sqrt(H(i,i) * H(j,j) - oracle([i j]));
    H(j,i) = H(i,j);
  end
end

% fix signs via BFS
T.pa = zeros(n,1);
T.depth = zeros(n,1);
Q = [1];
marked = eye(n);
for qi = 1:n
  i = Q(qi);
  for j = find(H(i,:) & ~marked(i,:)) % unmarked edges
    if T.pa(j) % non-tree edge
      path = find_chordless_path(H,T,i,j);
      if abs(det(H(path,path)) - oracle(path)) > 1e-10
        H(i,j) = -H(i,j);
        H(j,i) = -H(j,i);
      end
    else % tree edge
      T.pa(j) = i;
      T.depth(j) = T.depth(i)+1;
      Q(end+1) = j;
    end
    marked(i,j) = 1;
    marked(j,i) = 1;
  end

  if length(Q) == qi % disconnected graph
    Q(end+1) = find(~T.pa,1);
  end
end
